import json
from jwcrypto import jwk
from jose import jwt


class JWTUtil:

    @staticmethod
    def generate_jwk(key_type='RSA', size=2048):
        key = jwk.JWK.generate(kty=key_type, size=size)
        private_jwk = json.loads(key.export_private())
        public_jwk = json.loads(key.export_public())
        return private_jwk, public_jwk

    @staticmethod
    def encode(payload: dict, private_jwk: dict, algorithm='RS256') -> str:
        return jwt.encode(payload, key=private_jwk, algorithm=algorithm)

    @staticmethod
    def decode(token: str, public_jwk: dict, algorithm='RS256', options=None) -> dict:
        if options is None:
            options = {}

        options['verify_aud'] = options.get('verify_aud', False)

        return jwt.decode(token, key=public_jwk, algorithms=algorithm, options=options)

    @staticmethod
    def unverified_decode(token: str) -> dict:
        return jwt.get_unverified_claims(token)



#
#   Copyright 2020 The SpaceONE Authors.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.


import os
from setuptools import setup, find_packages

setup(
    name='spaceone-core',
    version=os.environ.get('PACKAGE_VERSION'),
    description='Cloudforet Core Library',
    long_description='',
    url='https://cloudforet.io/',
    author='MEGAZONE Cloud Corp.',
    author_email='admin@spaceone.dev',
    license='Apache License 2.0',
    packages=find_packages(),
    install_requires=[
        # grpc packages
        # 'grpcio',
        'protobuf==3.*',
        'grpcio-reflection',
        'google-api-core',
        'grpcio-health-checking',

        # fastapi packages
        'fastapi',
        'fastapi-utils',
        'uvicorn',

        # asyncio packages
        'asyncio',

        # data parser packages
        'PyYAML',
        'jsonschema',

        # test framework packages
        'unittest-xml-reporting',
        'factory-boy',

        # scheduler packages
        'schedule',
        'scheduler-cron',

        # cache packages
        'cachetools',

        # crypto(jwt) packages
        'pycryptodome',
        'jwcrypto',
        'python-jose',

        # utils packages
        'python-dateutil',
        'python-consul',
        'dnspython',

        # CLI packages
        'click',

        # model packages
        'pydantic',

        # tracing packages
        'opentelemetry-api',
        'opentelemetry-sdk',
        'opentelemetry-exporter-otlp-proto-grpc',
        'opentelemetry-instrumentation-logging',
        'opentelemetry-exporter-prometheus'
    ],
    zip_safe=False,
    entry_points={
        'console_scripts': [
            'spaceone = spaceone.core.command:cli',
        ]
    },
)
